@@ -1,6 +1,6 @@
 import copy
 
-from dataverk.utils.file_functions import url_encode
+from dataverk.utils.file_functions import remove_special_characters
 
 from dataverk.resources.base_resource import BaseResource
 
@@ -22,7 +22,7 @@ class PDFResource(BaseResource):
         self._schema = self._get_schema()
 
     def formatted_resource_name(self):
-        return url_encode(self._resource_name)
+        return remove_special_characters(self._resource_name)
 
     def _resource_path(self):
         return self._create_resource_path(
